@@ -33,9 +33,10 @@
 #  define PLASMA_DEPRECATED_NO_EXPORT PLASMA_NO_EXPORT PLASMA_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define PLASMA_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef PLASMA_NO_DEPRECATED
+#    define PLASMA_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* PLASMA_EXPORT_H */
